==> servicecatalog-1.7.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/servicecatalog/CfnStackSetConstraintProps.java <==
package software.amazon.awscdk.services.servicecatalog;

/**
 * Properties for defining a `AWS::ServiceCatalog::StackSetConstraint`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-stacksetconstraint.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-06T01:01:31.128Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnStackSetConstraintProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::ServiceCatalog::StackSetConstraint.AccountList`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-stacksetconstraint.html#cfn-servicecatalog-stacksetconstraint-accountlist
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.util.List<java.lang.String> getAccountList();

    /**
     * `AWS::ServiceCatalog::StackSetConstraint.AdminRole`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-stacksetconstraint.html#cfn-servicecatalog-stacksetconstraint-adminrole
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getAdminRole();

    /**
     * `AWS::ServiceCatalog::StackSetConstraint.Description`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-stacksetconstraint.html#cfn-servicecatalog-stacksetconstraint-description
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getDescription();

    /**
     * `AWS::ServiceCatalog::StackSetConstraint.ExecutionRole`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-stacksetconstraint.html#cfn-servicecatalog-stacksetconstraint-executionrole
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getExecutionRole();

    /**
     * `AWS::ServiceCatalog::StackSetConstraint.PortfolioId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-stacksetconstraint.html#cfn-servicecatalog-stacksetconstraint-portfolioid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getPortfolioId();

    /**
     * `AWS::ServiceCatalog::StackSetConstraint.ProductId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-stacksetconstraint.html#cfn-servicecatalog-stacksetconstraint-productid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getProductId();

    /**
     * `AWS::ServiceCatalog::StackSetConstraint.RegionList`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-stacksetconstraint.html#cfn-servicecatalog-stacksetconstraint-regionlist
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.util.List<java.lang.String> getRegionList();

    /**
     * `AWS::ServiceCatalog::StackSetConstraint.StackInstanceControl`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-stacksetconstraint.html#cfn-servicecatalog-stacksetconstraint-stackinstancecontrol
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getStackInstanceControl();

    /**
     * `AWS::ServiceCatalog::StackSetConstraint.AcceptLanguage`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-stacksetconstraint.html#cfn-servicecatalog-stacksetconstraint-acceptlanguage
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getAcceptLanguage();

    /**
     * @return a {@link Builder} of {@link CfnStackSetConstraintProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnStackSetConstraintProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Builder {
        private java.util.List<java.lang.String> accountList;
        private java.lang.String adminRole;
        private java.lang.String description;
        private java.lang.String executionRole;
        private java.lang.String portfolioId;
        private java.lang.String productId;
        private java.util.List<java.lang.String> regionList;
        private java.lang.String stackInstanceControl;
        private java.lang.String acceptLanguage;

        /**
         * Sets the value of AccountList
         * @param accountList `AWS::ServiceCatalog::StackSetConstraint.AccountList`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder accountList(java.util.List<java.lang.String> accountList) {
            this.accountList = accountList;
            return this;
        }

        /**
         * Sets the value of AdminRole
         * @param adminRole `AWS::ServiceCatalog::StackSetConstraint.AdminRole`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder adminRole(java.lang.String adminRole) {
            this.adminRole = adminRole;
            return this;
        }

        /**
         * Sets the value of Description
         * @param description `AWS::ServiceCatalog::StackSetConstraint.Description`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder description(java.lang.String description) {
            this.description = description;
            return this;
        }

        /**
         * Sets the value of ExecutionRole
         * @param executionRole `AWS::ServiceCatalog::StackSetConstraint.ExecutionRole`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder executionRole(java.lang.String executionRole) {
            this.executionRole = executionRole;
            return this;
        }

        /**
         * Sets the value of PortfolioId
         * @param portfolioId `AWS::ServiceCatalog::StackSetConstraint.PortfolioId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder portfolioId(java.lang.String portfolioId) {
            this.portfolioId = portfolioId;
            return this;
        }

        /**
         * Sets the value of ProductId
         * @param productId `AWS::ServiceCatalog::StackSetConstraint.ProductId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder productId(java.lang.String productId) {
            this.productId = productId;
            return this;
        }

        /**
         * Sets the value of RegionList
         * @param regionList `AWS::ServiceCatalog::StackSetConstraint.RegionList`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder regionList(java.util.List<java.lang.String> regionList) {
            this.regionList = regionList;
            return this;
        }

        /**
         * Sets the value of StackInstanceControl
         * @param stackInstanceControl `AWS::ServiceCatalog::StackSetConstraint.StackInstanceControl`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder stackInstanceControl(java.lang.String stackInstanceControl) {
            this.stackInstanceControl = stackInstanceControl;
            return this;
        }

        /**
         * Sets the value of AcceptLanguage
         * @param acceptLanguage `AWS::ServiceCatalog::StackSetConstraint.AcceptLanguage`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder acceptLanguage(java.lang.String acceptLanguage) {
            this.acceptLanguage = acceptLanguage;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnStackSetConstraintProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnStackSetConstraintProps build() {
            return new Jsii$Proxy(accountList, adminRole, description, executionRole, portfolioId, productId, regionList, stackInstanceControl, acceptLanguage);
        }

    }

    /**
     * An implementation for {@link CfnStackSetConstraintProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnStackSetConstraintProps {
        private final java.util.List<java.lang.String> accountList;
        private final java.lang.String adminRole;
        private final java.lang.String description;
        private final java.lang.String executionRole;
        private final java.lang.String portfolioId;
        private final java.lang.String productId;
        private final java.util.List<java.lang.String> regionList;
        private final java.lang.String stackInstanceControl;
        private final java.lang.String acceptLanguage;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.accountList = this.jsiiGet("accountList", java.util.List.class);
            this.adminRole = this.jsiiGet("adminRole", java.lang.String.class);
            this.description = this.jsiiGet("description", java.lang.String.class);
            this.executionRole = this.jsiiGet("executionRole", java.lang.String.class);
            this.portfolioId = this.jsiiGet("portfolioId", java.lang.String.class);
            this.productId = this.jsiiGet("productId", java.lang.String.class);
            this.regionList = this.jsiiGet("regionList", java.util.List.class);
            this.stackInstanceControl = this.jsiiGet("stackInstanceControl", java.lang.String.class);
            this.acceptLanguage = this.jsiiGet("acceptLanguage", java.lang.String.class);
        }


        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.util.List<java.lang.String> accountList, java.lang.String adminRole, java.lang.String description, java.lang.String executionRole, java.lang.String portfolioId, java.lang.String productId, java.util.List<java.lang.String> regionList, java.lang.String stackInstanceControl, java.lang.String acceptLanguage) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.accountList = java.util.Objects.requireNonNull(accountList, "accountList is required");
            this.adminRole = java.util.Objects.requireNonNull(adminRole, "adminRole is required");
            this.description = java.util.Objects.requireNonNull(description, "description is required");
            this.executionRole = java.util.Objects.requireNonNull(executionRole, "executionRole is required");
            this.portfolioId = java.util.Objects.requireNonNull(portfolioId, "portfolioId is required");
            this.productId = java.util.Objects.requireNonNull(productId, "productId is required");
            this.regionList = java.util.Objects.requireNonNull(regionList, "regionList is required");
            this.stackInstanceControl = java.util.Objects.requireNonNull(stackInstanceControl, "stackInstanceControl is required");
            this.acceptLanguage = acceptLanguage;
        }

        @Override
        public java.util.List<java.lang.String> getAccountList() {
            return this.accountList;
        }

        @Override
        public java.lang.String getAdminRole() {
            return this.adminRole;
        }

        @Override
        public java.lang.String getDescription() {
            return this.description;
        }

        @Override
        public java.lang.String getExecutionRole() {
            return this.executionRole;
        }

        @Override
        public java.lang.String getPortfolioId() {
            return this.portfolioId;
        }

        @Override
        public java.lang.String getProductId() {
            return this.productId;
        }

        @Override
        public java.util.List<java.lang.String> getRegionList() {
            return this.regionList;
        }

        @Override
        public java.lang.String getStackInstanceControl() {
            return this.stackInstanceControl;
        }

        @Override
        public java.lang.String getAcceptLanguage() {
            return this.acceptLanguage;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("accountList", om.valueToTree(this.getAccountList()));
            obj.set("adminRole", om.valueToTree(this.getAdminRole()));
            obj.set("description", om.valueToTree(this.getDescription()));
            obj.set("executionRole", om.valueToTree(this.getExecutionRole()));
            obj.set("portfolioId", om.valueToTree(this.getPortfolioId()));
            obj.set("productId", om.valueToTree(this.getProductId()));
            obj.set("regionList", om.valueToTree(this.getRegionList()));
            obj.set("stackInstanceControl", om.valueToTree(this.getStackInstanceControl()));
            if (this.getAcceptLanguage() != null) {
                obj.set("acceptLanguage", om.valueToTree(this.getAcceptLanguage()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnStackSetConstraintProps.Jsii$Proxy that = (CfnStackSetConstraintProps.Jsii$Proxy) o;

            if (!accountList.equals(that.accountList)) return false;
            if (!adminRole.equals(that.adminRole)) return false;
            if (!description.equals(that.description)) return false;
            if (!executionRole.equals(that.executionRole)) return false;
            if (!portfolioId.equals(that.portfolioId)) return false;
            if (!productId.equals(that.productId)) return false;
            if (!regionList.equals(that.regionList)) return false;
            if (!stackInstanceControl.equals(that.stackInstanceControl)) return false;
            return this.acceptLanguage != null ? this.acceptLanguage.equals(that.acceptLanguage) : that.acceptLanguage == null;
        }

        @Override
        public int hashCode() {
            int result = this.accountList.hashCode();
            result = 31 * result + (this.adminRole.hashCode());
            result = 31 * result + (this.description.hashCode());
            result = 31 * result + (this.executionRole.hashCode());
            result = 31 * result + (this.portfolioId.hashCode());
            result = 31 * result + (this.productId.hashCode());
            result = 31 * result + (this.regionList.hashCode());
            result = 31 * result + (this.stackInstanceControl.hashCode());
            result = 31 * result + (this.acceptLanguage != null ? this.acceptLanguage.hashCode() : 0);
            return result;
        }

    }
}

==> servicecatalog-1.9.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/servicecatalog/CfnStackSetConstraintProps.java <==
package software.amazon.awscdk.services.servicecatalog;

/**
 * Properties for defining a `AWS::ServiceCatalog::StackSetConstraint`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-stacksetconstraint.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-20T09:53:44.182Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnStackSetConstraintProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::ServiceCatalog::StackSetConstraint.AccountList`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-stacksetconstraint.html#cfn-servicecatalog-stacksetconstraint-accountlist
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.util.List<java.lang.String> getAccountList();

    /**
     * `AWS::ServiceCatalog::StackSetConstraint.AdminRole`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-stacksetconstraint.html#cfn-servicecatalog-stacksetconstraint-adminrole
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getAdminRole();

    /**
     * `AWS::ServiceCatalog::StackSetConstraint.Description`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-stacksetconstraint.html#cfn-servicecatalog-stacksetconstraint-description
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getDescription();

    /**
     * `AWS::ServiceCatalog::StackSetConstraint.ExecutionRole`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-stacksetconstraint.html#cfn-servicecatalog-stacksetconstraint-executionrole
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getExecutionRole();

    /**
     * `AWS::ServiceCatalog::StackSetConstraint.PortfolioId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-stacksetconstraint.html#cfn-servicecatalog-stacksetconstraint-portfolioid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getPortfolioId();

    /**
     * `AWS::ServiceCatalog::StackSetConstraint.ProductId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-stacksetconstraint.html#cfn-servicecatalog-stacksetconstraint-productid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getProductId();

    /**
     * `AWS::ServiceCatalog::StackSetConstraint.RegionList`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-stacksetconstraint.html#cfn-servicecatalog-stacksetconstraint-regionlist
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.util.List<java.lang.String> getRegionList();

    /**
     * `AWS::ServiceCatalog::StackSetConstraint.StackInstanceControl`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-stacksetconstraint.html#cfn-servicecatalog-stacksetconstraint-stackinstancecontrol
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getStackInstanceControl();

    /**
     * `AWS::ServiceCatalog::StackSetConstraint.AcceptLanguage`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-stacksetconstraint.html#cfn-servicecatalog-stacksetconstraint-acceptlanguage
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getAcceptLanguage();

    /**
     * @return a {@link Builder} of {@link CfnStackSetConstraintProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnStackSetConstraintProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.util.List<java.lang.String> accountList;
        private java.lang.String adminRole;
        private java.lang.String description;
        private java.lang.String executionRole;
        private java.lang.String portfolioId;
        private java.lang.String productId;
        private java.util.List<java.lang.String> regionList;
        private java.lang.String stackInstanceControl;
        private java.lang.String acceptLanguage;

        /**
         * Sets the value of AccountList
         * @param accountList `AWS::ServiceCatalog::StackSetConstraint.AccountList`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder accountList(java.util.List<java.lang.String> accountList) {
            this.accountList = accountList;
            return this;
        }

        /**
         * Sets the value of AdminRole
         * @param adminRole `AWS::ServiceCatalog::StackSetConstraint.AdminRole`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder adminRole(java.lang.String adminRole) {
            this.adminRole = adminRole;
            return this;
        }

        /**
         * Sets the value of Description
         * @param description `AWS::ServiceCatalog::StackSetConstraint.Description`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder description(java.lang.String description) {
            this.description = description;
            return this;
        }

        /**
         * Sets the value of ExecutionRole
         * @param executionRole `AWS::ServiceCatalog::StackSetConstraint.ExecutionRole`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder executionRole(java.lang.String executionRole) {
            this.executionRole = executionRole;
            return this;
        }

        /**
         * Sets the value of PortfolioId
         * @param portfolioId `AWS::ServiceCatalog::StackSetConstraint.PortfolioId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder portfolioId(java.lang.String portfolioId) {
            this.portfolioId = portfolioId;
            return this;
        }

        /**
         * Sets the value of ProductId
         * @param productId `AWS::ServiceCatalog::StackSetConstraint.ProductId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder productId(java.lang.String productId) {
            this.productId = productId;
            return this;
        }

        /**
         * Sets the value of RegionList
         * @param regionList `AWS::ServiceCatalog::StackSetConstraint.RegionList`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder regionList(java.util.List<java.lang.String> regionList) {
            this.regionList = regionList;
            return this;
        }

        /**
         * Sets the value of StackInstanceControl
         * @param stackInstanceControl `AWS::ServiceCatalog::StackSetConstraint.StackInstanceControl`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder stackInstanceControl(java.lang.String stackInstanceControl) {
            this.stackInstanceControl = stackInstanceControl;
            return this;
        }

        /**
         * Sets the value of AcceptLanguage
         * @param acceptLanguage `AWS::ServiceCatalog::StackSetConstraint.AcceptLanguage`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder acceptLanguage(java.lang.String acceptLanguage) {
            this.acceptLanguage = acceptLanguage;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnStackSetConstraintProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnStackSetConstraintProps build() {
            return new Jsii$Proxy(accountList, adminRole, description, executionRole, portfolioId, productId, regionList, stackInstanceControl, acceptLanguage);
        }
    }

    /**
     * An implementation for {@link CfnStackSetConstraintProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnStackSetConstraintProps {
        private final java.util.List<java.lang.String> accountList;
        private final java.lang.String adminRole;
        private final java.lang.String description;
        private final java.lang.String executionRole;
        private final java.lang.String portfolioId;
        private final java.lang.String productId;
        private final java.util.List<java.lang.String> regionList;
        private final java.lang.String stackInstanceControl;
        private final java.lang.String acceptLanguage;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.accountList = this.jsiiGet("accountList", java.util.List.class);
            this.adminRole = this.jsiiGet("adminRole", java.lang.String.class);
            this.description = this.jsiiGet("description", java.lang.String.class);
            this.executionRole = this.jsiiGet("executionRole", java.lang.String.class);
            this.portfolioId = this.jsiiGet("portfolioId", java.lang.String.class);
            this.productId = this.jsiiGet("productId", java.lang.String.class);
            this.regionList = this.jsiiGet("regionList", java.util.List.class);
            this.stackInstanceControl = this.jsiiGet("stackInstanceControl", java.lang.String.class);
            this.acceptLanguage = this.jsiiGet("acceptLanguage", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.util.List<java.lang.String> accountList, java.lang.String adminRole, java.lang.String description, java.lang.String executionRole, java.lang.String portfolioId, java.lang.String productId, java.util.List<java.lang.String> regionList, java.lang.String stackInstanceControl, java.lang.String acceptLanguage) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.accountList = java.util.Objects.requireNonNull(accountList, "accountList is required");
            this.adminRole = java.util.Objects.requireNonNull(adminRole, "adminRole is required");
            this.description = java.util.Objects.requireNonNull(description, "description is required");
            this.executionRole = java.util.Objects.requireNonNull(executionRole, "executionRole is required");
            this.portfolioId = java.util.Objects.requireNonNull(portfolioId, "portfolioId is required");
            this.productId = java.util.Objects.requireNonNull(productId, "productId is required");
            this.regionList = java.util.Objects.requireNonNull(regionList, "regionList is required");
            this.stackInstanceControl = java.util.Objects.requireNonNull(stackInstanceControl, "stackInstanceControl is required");
            this.acceptLanguage = acceptLanguage;
        }

        @Override
        public java.util.List<java.lang.String> getAccountList() {
            return this.accountList;
        }

        @Override
        public java.lang.String getAdminRole() {
            return this.adminRole;
        }

        @Override
        public java.lang.String getDescription() {
            return this.description;
        }

        @Override
        public java.lang.String getExecutionRole() {
            return this.executionRole;
        }

        @Override
        public java.lang.String getPortfolioId() {
            return this.portfolioId;
        }

        @Override
        public java.lang.String getProductId() {
            return this.productId;
        }

        @Override
        public java.util.List<java.lang.String> getRegionList() {
            return this.regionList;
        }

        @Override
        public java.lang.String getStackInstanceControl() {
            return this.stackInstanceControl;
        }

        @Override
        public java.lang.String getAcceptLanguage() {
            return this.acceptLanguage;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("accountList", om.valueToTree(this.getAccountList()));
            obj.set("adminRole", om.valueToTree(this.getAdminRole()));
            obj.set("description", om.valueToTree(this.getDescription()));
            obj.set("executionRole", om.valueToTree(this.getExecutionRole()));
            obj.set("portfolioId", om.valueToTree(this.getPortfolioId()));
            obj.set("productId", om.valueToTree(this.getProductId()));
            obj.set("regionList", om.valueToTree(this.getRegionList()));
            obj.set("stackInstanceControl", om.valueToTree(this.getStackInstanceControl()));
            if (this.getAcceptLanguage() != null) {
                obj.set("acceptLanguage", om.valueToTree(this.getAcceptLanguage()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnStackSetConstraintProps.Jsii$Proxy that = (CfnStackSetConstraintProps.Jsii$Proxy) o;

            if (!accountList.equals(that.accountList)) return false;
            if (!adminRole.equals(that.adminRole)) return false;
            if (!description.equals(that.description)) return false;
            if (!executionRole.equals(that.executionRole)) return false;
            if (!portfolioId.equals(that.portfolioId)) return false;
            if (!productId.equals(that.productId)) return false;
            if (!regionList.equals(that.regionList)) return false;
            if (!stackInstanceControl.equals(that.stackInstanceControl)) return false;
            return this.acceptLanguage != null ? this.acceptLanguage.equals(that.acceptLanguage) : that.acceptLanguage == null;
        }

        @Override
        public int hashCode() {
            int result = this.accountList.hashCode();
            result = 31 * result + (this.adminRole.hashCode());
            result = 31 * result + (this.description.hashCode());
            result = 31 * result + (this.executionRole.hashCode());
            result = 31 * result + (this.portfolioId.hashCode());
            result = 31 * result + (this.productId.hashCode());
            result = 31 * result + (this.regionList.hashCode());
            result = 31 * result + (this.stackInstanceControl.hashCode());
            result = 31 * result + (this.acceptLanguage != null ? this.acceptLanguage.hashCode() : 0);
            return result;
        }
    }
}
